Type Alias Ping

pub type Ping = Ping;
Available on crate feature wayland and Linux only.
The ping event source

You can insert it in your event loop to receive pings.

If you use it directly, it will automatically remove itself from the event loop once all Ping instances are dropped.

Aliased Type

pub struct Ping { /* private fields */ }