Type Alias PingSource

pub type PingSource = PingSource;
Available on crate feature wayland and Linux only.
The Ping handle

This handle can be cloned and sent accross threads. It can be used to send pings to the PingSource.

Aliased Type

pub struct PingSource { /* private fields */ }